Commitable

Trait Commitable 

pub trait Commitable: VeTensorContext { }
Marker trait for contexts that can commit to DmTensor. Group is intentionally excluded so users must zip the groups first.

Implementors