pub struct DmTensor<D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M> { /* private fields */ }Expand description
Tensor stored in data memory.
Implementations
Sourceimpl<D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M> DmTensor<D, Chip, Cluster, Slice, Element>
impl<D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M> DmTensor<D, Chip, Cluster, Slice, Element>
Sourcepub unsafe fn from_addr(address: Address) -> Self
pub unsafe fn from_addr(address: Address) -> Self
Creates a DM tensor handle at the given raw address.
Safety
The caller must ensure that the underlying data layout is compatible with the tensor mapping.
Sourcepub fn to_hbm<Element2: M>(
&self,
_dma: &mut DmaContext<{ Dma::Tensor }>,
address: Address,
) -> HbmTensor<D, Chip, Element2>
pub fn to_hbm<Element2: M>( &self, _dma: &mut DmaContext<{ Dma::Tensor }>, address: Address, ) -> HbmTensor<D, Chip, Element2>
Converts to HBM tensor.
Sourcepub fn dma_scatter<Key: M, Element2: M, Element3: M>(
&self,
index: &HbmTensor<i32, Chip, Element3>,
output: &mut HbmTensor<D, Chip, Element2>,
scaled: bool,
)
pub fn dma_scatter<Key: M, Element2: M, Element3: M>( &self, index: &HbmTensor<i32, Chip, Element3>, output: &mut HbmTensor<D, Chip, Element2>, scaled: bool, )
Scatter SRAM values to DRAM at positions given by index tensor.
data: [N, K, V]
index: [N, K]
output: [N, X, V]
(data - Chip).divide(K) = [N, V]Sourcepub fn to_dm<Slice2: M, Element2: M>(
&self,
_dma: &mut DmaContext<{ Dma::Tensor }>,
address: Address,
) -> DmTensor<D, Chip, Cluster, Slice2, Element2>
pub fn to_dm<Slice2: M, Element2: M>( &self, _dma: &mut DmaContext<{ Dma::Tensor }>, address: Address, ) -> DmTensor<D, Chip, Cluster, Slice2, Element2>
Converts to data memory tensor.
Sourcepub fn to_dm_pcopy<Slice2: M, Element2: M>(
&self,
sub: &mut TuContext<{ Tu::Sub }>,
dst: &mut DmTensor<D, Chip, Cluster, Slice2, Element2>,
)
pub fn to_dm_pcopy<Slice2: M, Element2: M>( &self, sub: &mut TuContext<{ Tu::Sub }>, dst: &mut DmTensor<D, Chip, Cluster, Slice2, Element2>, )
Copies data to another DM tensor via parallel copy.
Convenience wrapper: self.view().to_dm_view_pcopy(sub, dst.view_mut()).
Sourcepub fn view<'l>(&'l self) -> DmTensorView<'l, D, Chip, Cluster, Slice, Element>
pub fn view<'l>(&'l self) -> DmTensorView<'l, D, Chip, Cluster, Slice, Element>
Creates immutable views by splitting along a tile expression.
Sourcepub fn view_mut<'l>(
&'l mut self,
) -> DmTensorViewMut<'l, D, Chip, Cluster, Slice, Element>
pub fn view_mut<'l>( &'l mut self, ) -> DmTensorViewMut<'l, D, Chip, Cluster, Slice, Element>
Creates mutable views by splitting along a tile expression.
Sourcepub unsafe fn reshape<Chip2: M, Cluster2: M, Slice2: M, Element2: M>(
self,
) -> DmTensor<D, Chip2, Cluster2, Slice2, Element2>
pub unsafe fn reshape<Chip2: M, Cluster2: M, Slice2: M, Element2: M>( self, ) -> DmTensor<D, Chip2, Cluster2, Slice2, Element2>
Reshapes the tensor to a different mapping at the same address.
Safety
The caller must ensure that the new mapping accurately describes the data currently at this address.