pub struct DmTensorView<'l, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M> { /* private fields */ }Expand description
View of a data memory tensor.
Implementations
Sourceimpl<'l, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M> DmTensorView<'l, D, Chip, Cluster, Slice, Element>
impl<'l, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M> DmTensorView<'l, D, Chip, Cluster, Slice, Element>
Sourcepub fn to_hbm_view<Element2: M>(
self,
_dma: &mut DmaContext<{ Dma::Tensor }>,
dst: HbmTensorViewMut<'l, D, Chip, Element2>,
)
pub fn to_hbm_view<Element2: M>( self, _dma: &mut DmaContext<{ Dma::Tensor }>, dst: HbmTensorViewMut<'l, D, Chip, Element2>, )
Writes data to a mutable tensor view for HBM.
Sourcepub fn to_dm_view<Slice2: M, Element2: M>(
self,
_dma: &mut DmaContext<{ Dma::Tensor }>,
dst: DmTensorViewMut<'l, D, Chip, Cluster, Slice2, Element2>,
)
pub fn to_dm_view<Slice2: M, Element2: M>( self, _dma: &mut DmaContext<{ Dma::Tensor }>, dst: DmTensorViewMut<'l, D, Chip, Cluster, Slice2, Element2>, )
Writes data to a mutable tensor view for data memory.
Sourcepub fn to_dm_view_pcopy<Slice2: M, Element2: M>(
self,
_sub: &mut TuContext<{ Tu::Sub }>,
dst: DmTensorViewMut<'l, D, Chip, Cluster, Slice2, Element2>,
)
pub fn to_dm_view_pcopy<Slice2: M, Element2: M>( self, _sub: &mut TuContext<{ Tu::Sub }>, dst: DmTensorViewMut<'l, D, Chip, Cluster, Slice2, Element2>, )
Writes data to a mutable tensor view for data memory.
Sourcepub fn chip_tile<Index: M, const LEN: usize, Chip2: M>(
&self,
start: usize,
) -> DmTensorView<'l, D, Chip2, Cluster, Slice, Element>
pub fn chip_tile<Index: M, const LEN: usize, Chip2: M>( &self, start: usize, ) -> DmTensorView<'l, D, Chip2, Cluster, Slice, Element>
Creates immutable views by splitting along a tile expression over Chip.
Sourcepub fn cluster_tile<Index: M, const LEN: usize, Cluster2: M>(
&self,
start: usize,
) -> DmTensorView<'l, D, Chip, Cluster2, Slice, Element>
pub fn cluster_tile<Index: M, const LEN: usize, Cluster2: M>( &self, start: usize, ) -> DmTensorView<'l, D, Chip, Cluster2, Slice, Element>
Creates immutable views by splitting along a tile expression over Cluster.
Sourcepub fn slice_tile<Index: M, const LEN: usize, Slice2: M>(
&self,
start: usize,
) -> DmTensorView<'l, D, Chip, Cluster, Slice2, Element>
pub fn slice_tile<Index: M, const LEN: usize, Slice2: M>( &self, start: usize, ) -> DmTensorView<'l, D, Chip, Cluster, Slice2, Element>
Creates immutable views by splitting along a tile expression over Slice.