pub struct RawTensor<D: Scalar> { /* private fields */ }Expand description
Tensor with scalar type D.
Implementations
Sourceimpl<D: Scalar> RawTensor<D>
impl<D: Scalar> RawTensor<D>
Sourcepub fn from_elem<Mapping: M>(elem: Opt<D>) -> Self
pub fn from_elem<Mapping: M>(elem: Opt<D>) -> Self
Similar to from_vec, but creates a new tensor with uninit elements.
Sourcepub fn from_vec<Mapping: M>(data: Vec<Opt<D>>) -> Self
pub fn from_vec<Mapping: M>(data: Vec<Opt<D>>) -> Self
Creates a new tensor from a vector.
Mapping determines the axes of the tensor, and data is a flat vector containing the tensor elements in the order sorted by the axes.
Sourcepub fn from_fn<Mapping: M, F>(f: F) -> Self
pub fn from_fn<Mapping: M, F>(f: F) -> Self
Creates a new tensor from a mapping and a function.
Sourcepub fn zip_with<D2: Scalar, D3: Scalar, F>(
&self,
other: &RawTensor<D2>,
f: F,
) -> RawTensor<D3>
pub fn zip_with<D2: Scalar, D3: Scalar, F>( &self, other: &RawTensor<D2>, f: F, ) -> RawTensor<D3>
Sourcepub fn reduce(
&self,
retain_axes: &[Term],
reduce_fn: impl Fn(Opt<D>, Opt<D>) -> Opt<D>,
identity: Opt<D>,
) -> RawTensor<D>
pub fn reduce( &self, retain_axes: &[Term], reduce_fn: impl Fn(Opt<D>, Opt<D>) -> Opt<D>, identity: Opt<D>, ) -> RawTensor<D>
Reduces axes not in retain_axes using a custom binary function and identity.
Sourcepub fn reduce_add(&self, retain_axes: &[Term]) -> RawTensor<D>
pub fn reduce_add(&self, retain_axes: &[Term]) -> RawTensor<D>
Performs reduction (sum) over axes. The axes to retain are specified by their terms.
Sourcepub fn write_broadcast(
&mut self,
src: &Self,
unicast: FMapping,
broadcast: FMapping,
src_offset: &Index,
dst_offset: &Index,
)
pub fn write_broadcast( &mut self, src: &Self, unicast: FMapping, broadcast: FMapping, src_offset: &Index, dst_offset: &Index, )
Broadcasts and writes data from another tensor based on the given mappings and offsets.
Arguments
src- Source tensor to read data from.unicast- Mapping for 1-to-1 mapping dimensions.broadcast- Mapping for broadcasted dimensions.src_offset- Offset to apply to the source tensor indices.dst_offset- Offset to apply to the destination (self) tensor indices.