pub struct VectorInitTensor<'l, const T: Tu, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M> { /* private fields */ }Expand description
VE input after vector_init(), before choosing the first block.
Implementations
Sourceimpl<'l, const T: Tu, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M> VectorInitTensor<'l, T, D, Chip, Cluster, Slice, Time, Packet>
impl<'l, const T: Tu, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M> VectorInitTensor<'l, T, D, Chip, Cluster, Slice, Time, Packet>
Sourceimpl<'l, const T: Tu, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M> VectorInitTensor<'l, T, D, Chip, Cluster, Slice, Time, Packet>
impl<'l, const T: Tu, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M> VectorInitTensor<'l, T, D, Chip, Cluster, Slice, Time, Packet>
Sourcepub fn vector_intra_slice_branch(
self,
branch: BranchMode,
) -> VectorBranchTensor<'l, T, D, Chip, Cluster, Slice, Time, Packet, D, NoTensor, { VeOrder::IntraFirst }>
pub fn vector_intra_slice_branch( self, branch: BranchMode, ) -> VectorBranchTensor<'l, T, D, Chip, Cluster, Slice, Time, Packet, D, NoTensor, { VeOrder::IntraFirst }>
Enters VE intra-slice pipeline (single stream).
Sourcepub fn vector_intra_slice_unzip<I: AxisName, TileTime: M, SplitTime: M>(
self,
) -> VectorTensorPair<'l, T, D, Branch, Chip, Cluster, Slice, SplitTime, Packet>
pub fn vector_intra_slice_unzip<I: AxisName, TileTime: M, SplitTime: M>( self, ) -> VectorTensorPair<'l, T, D, Branch, Chip, Cluster, Slice, SplitTime, Packet>
Enters VE intra-slice pipeline (two-group / unzip).
Sourceimpl<'l, const T: Tu, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M> VectorInitTensor<'l, T, i32, Chip, Cluster, Slice, Time, Packet>
impl<'l, const T: Tu, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M> VectorInitTensor<'l, T, i32, Chip, Cluster, Slice, Time, Packet>
Sourcepub fn vector_inter_slice_reduce<Slice2: M, Time2: M>(
self,
op: InterSliceReduceOpI32,
) -> VectorInterSliceReduceTensor<'l, T, i32, Chip, Cluster, Slice2, Time2, Packet, { VeOrder::InterFirst }>
pub fn vector_inter_slice_reduce<Slice2: M, Time2: M>( self, op: InterSliceReduceOpI32, ) -> VectorInterSliceReduceTensor<'l, T, i32, Chip, Cluster, Slice2, Time2, Packet, { VeOrder::InterFirst }>
Performs inter-slice reduce for i32 as the first VE operation.
Sourceimpl<'l, const T: Tu, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M> VectorInitTensor<'l, T, f32, Chip, Cluster, Slice, Time, Packet>
impl<'l, const T: Tu, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M> VectorInitTensor<'l, T, f32, Chip, Cluster, Slice, Time, Packet>
Sourcepub fn vector_inter_slice_reduce<Slice2: M, Time2: M>(
self,
op: InterSliceReduceOpF32,
) -> VectorInterSliceReduceTensor<'l, T, f32, Chip, Cluster, Slice2, Time2, Packet, { VeOrder::InterFirst }>
pub fn vector_inter_slice_reduce<Slice2: M, Time2: M>( self, op: InterSliceReduceOpF32, ) -> VectorInterSliceReduceTensor<'l, T, f32, Chip, Cluster, Slice2, Time2, Packet, { VeOrder::InterFirst }>
Performs inter-slice reduce for f32 as the first VE operation.