VeScalar

Trait VeScalar 

pub trait VeScalar: Scalar {
    const KIND: VeScalarKind;
}
Marker trait for scalar types supported by Vector Engine. Only i32 and f32 are supported.

This trait is sealed and cannot be implemented outside this module.

Required Associated Constants

const KIND: VeScalarKind

The kind of this scalar type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl VeScalar for f32

Source

const KIND: VeScalarKind = VeScalarKind::F32

Source

impl VeScalar for i32

Source

const KIND: VeScalarKind = VeScalarKind::I32

Implementors