pub trait Commitable: VeTensorContext { }Expand description
Marker trait for contexts that can commit to DmTensor.
Group is intentionally excluded so users must zip the groups first.
pub trait Commitable: VeTensorContext { }Marker trait for contexts that can commit to DmTensor.
Group is intentionally excluded so users must zip the groups first.