pub struct HbmTensor<D: Scalar, Chip: M, Element: M> { /* private fields */ }Expand description
Tensor stored in HBM memory.
Implementations
Sourceimpl<D: Scalar, Chip: M, Element: M> HbmTensor<D, Chip, Element>
impl<D: Scalar, Chip: M, Element: M> HbmTensor<D, Chip, Element>
Sourcepub unsafe fn from_addr(address: Address) -> Self
pub unsafe fn from_addr(address: Address) -> Self
Creates an HBM tensor handle at the given raw address.
Safety
The caller must ensure that the underlying data layout is compatible with the tensor mapping.
Sourcepub async fn to_host<Element2: M>(
&self,
_dma: &mut DmaContext<{ Dma::Pcie }>,
) -> HostTensor<D, Element2>
pub async fn to_host<Element2: M>( &self, _dma: &mut DmaContext<{ Dma::Pcie }>, ) -> HostTensor<D, Element2>
Converts to host tensor.
TODO: we should optionally receive the intermediate stream’s mapping expression.
Sourcepub fn to_hbm<const DMA: Dma, Element2: M>(
&self,
_dma: &mut DmaContext<DMA>,
address: Address,
) -> HbmTensor<D, Chip, Element2>
pub fn to_hbm<const DMA: Dma, Element2: M>( &self, _dma: &mut DmaContext<DMA>, address: Address, ) -> HbmTensor<D, Chip, Element2>
Converts to HBM tensor.
Sourcepub fn dma_gather<Cluster2: M, Slice2: M, Element2: M, Element3: M>(
&self,
_index_tensor: &HbmTensor<i32, Chip, Element3>,
_address: Address,
) -> DmTensor<D, Chip, Cluster2, Slice2, Element2>
pub fn dma_gather<Cluster2: M, Slice2: M, Element2: M, Element3: M>( &self, _index_tensor: &HbmTensor<i32, Chip, Element3>, _address: Address, ) -> DmTensor<D, Chip, Cluster2, Slice2, Element2>
Gather DRAM rows into SRAM at positions given by index tensor.
Implements index_select along dim 0: output[i] = self[index[i]].
Inverse of DmTensor::dma_scatter.
TODO: implement CPU reference and LIR translation (same pattern as dma_scatter).
Sourcepub fn view<'l>(&'l self) -> HbmTensorView<'l, D, Chip, Element>
pub fn view<'l>(&'l self) -> HbmTensorView<'l, D, Chip, Element>
Creates mutable views by splitting along a tile expression.
Sourcepub fn view_mut<'l>(&'l mut self) -> HbmTensorViewMut<'l, D, Chip, Element>
pub fn view_mut<'l>(&'l mut self) -> HbmTensorViewMut<'l, D, Chip, Element>
Creates mutable views by splitting along a tile expression.