pub struct Tensor<D: Scalar, Mapping: M> { /* private fields */ }Expand description
Tensor with scalar type D with axes determined by Mapping.
Implementations
Sourceimpl<D: Scalar, Mapping: M> Tensor<D, Mapping>
impl<D: Scalar, Mapping: M> Tensor<D, Mapping>
Sourcepub fn to_buf(&self) -> Vec<Opt<D>>
pub fn to_buf(&self) -> Vec<Opt<D>>
Returns the tensor data as a flat vector in the physical layout order defined by Mapping.
Sourcepub fn rand(rng: &mut impl Rng) -> Selfwhere
StandardUniform: Distribution<D>,
pub fn rand(rng: &mut impl Rng) -> Selfwhere
StandardUniform: Distribution<D>,
Creates a random tensor.
Sourcepub fn view_mut<'l>(&'l mut self) -> TensorViewMut<'l, D, Mapping>
pub fn view_mut<'l>(&'l mut self) -> TensorViewMut<'l, D, Mapping>
Creates a mutable view of the tensor.
Sourcepub fn view<'l>(&'l self) -> TensorView<'l, D, Mapping>
pub fn view<'l>(&'l self) -> TensorView<'l, D, Mapping>
Creates an immutable view of the tensor.
Sourcepub fn data_mut(&mut self) -> &mut ArrayD<Opt<D>>
pub fn data_mut(&mut self) -> &mut ArrayD<Opt<D>>
Returns a mutable reference to the underlying data array.
Sourcepub unsafe fn transmute<Mapping2: M>(self) -> Tensor<D, Mapping2>
pub unsafe fn transmute<Mapping2: M>(self) -> Tensor<D, Mapping2>
Transmutes the tensor to a different mapping.
Safety
The caller must ensure that the underlying data layout is compatible with the new mapping.
Sourcepub unsafe fn reshape<Src: M, Dst: M, Mapping2: M>(self) -> Tensor<D, Mapping2>
pub unsafe fn reshape<Src: M, Dst: M, Mapping2: M>(self) -> Tensor<D, Mapping2>
Reshapes the tensor to a different mapping. change Src into Dst, final mapping is Mapping2.
Safety
TODO(jeongmin.park); document safety.
Sourcepub fn zip_with<D2: Scalar, D3: Scalar, F>(
&self,
other: &Tensor<D2, Mapping>,
f: F,
) -> Tensor<D3, Mapping>
pub fn zip_with<D2: Scalar, D3: Scalar, F>( &self, other: &Tensor<D2, Mapping>, f: F, ) -> Tensor<D3, Mapping>
Zips two tensors with a function.
Sourcepub fn reduce_add<Dst: M>(&self) -> Tensor<D, Dst>
pub fn reduce_add<Dst: M>(&self) -> Tensor<D, Dst>
Performs reduction (sum) over axes not present in Dst.
Sourcepub fn reduce<Dst: M>(
&self,
reduce_fn: impl Fn(Opt<D>, Opt<D>) -> Opt<D>,
identity: Opt<D>,
) -> Tensor<D, Dst>
pub fn reduce<Dst: M>( &self, reduce_fn: impl Fn(Opt<D>, Opt<D>) -> Opt<D>, identity: Opt<D>, ) -> Tensor<D, Dst>
Reduces axes present in self but absent in Dst, using a custom reduce function.
Sourcepub fn reduce_then_broadcast<Dst: M>(&self) -> Tensor<D, Dst>
pub fn reduce_then_broadcast<Dst: M>(&self) -> Tensor<D, Dst>
Performs reduction followed by broadcasting to match destination axes. This is useful when the destination has broadcast axes that should be preserved.
Examples
let src: Tensor<f32, m![ABCD]> = Tensor::from_vec(...); // Shape: ABCD
let dst: Tensor<f32, m![ABE]> = src.reduce_then_broadcast(); // Reduces CD, broadcasts to ABESourcepub fn reduce_then_broadcast_with<Dst: M>(
&self,
reduce_fn: impl Fn(Opt<D>, Opt<D>) -> Opt<D>,
identity: Opt<D>,
) -> Tensor<D, Dst>
pub fn reduce_then_broadcast_with<Dst: M>( &self, reduce_fn: impl Fn(Opt<D>, Opt<D>) -> Opt<D>, identity: Opt<D>, ) -> Tensor<D, Dst>
Performs reduction with a custom function, followed by broadcasting to match destination axes.