pub struct TuContext<const T: Tu> { /* private fields */ }Expand description
Context for a specific tensor unit.
Implementations
Sourceimpl<const T: Tu> TuContext<T>
impl<const T: Tu> TuContext<T>
Sourcepub fn begin<'l, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M>(
&'l mut self,
tensor: DmTensorView<'l, D, Chip, Cluster, Slice, Element>,
) -> BeginTensor<'l, T, D, Chip, Cluster, Slice, Identity, Element>
pub fn begin<'l, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M>( &'l mut self, tensor: DmTensorView<'l, D, Chip, Cluster, Slice, Element>, ) -> BeginTensor<'l, T, D, Chip, Cluster, Slice, Identity, Element>
Begin a tensor unit operation in this context.
Sourcepub fn begin_interleaved<'l, I: AxisName, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M>(
&'l mut self,
lhs: DmTensorView<'l, D, Chip, Cluster, Slice, Element>,
rhs: DmTensorView<'l, D, Chip, Cluster, Slice, Element>,
) -> BeginTensor<'l, T, D, Chip, Cluster, Slice, Symbol<I>, Element>
pub fn begin_interleaved<'l, I: AxisName, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M>( &'l mut self, lhs: DmTensorView<'l, D, Chip, Cluster, Slice, Element>, rhs: DmTensorView<'l, D, Chip, Cluster, Slice, Element>, ) -> BeginTensor<'l, T, D, Chip, Cluster, Slice, Symbol<I>, Element>
Begin a tensor unit operation in this context with interleaved tensors.
Sourceimpl TuContext<{ Tu::Sub }>
impl TuContext<{ Tu::Sub }>
Sourcepub fn parallel_copy_cluster_slice<'l, const CLUSTER_DIM: usize, AxisToSlice: M, AxisSlicedElement: M, Element2: M, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M>(
&mut self,
tensor: DmTensorView<'l, D, Chip, Cluster, Slice, Element>,
slice_indices: &[usize; CLUSTER_DIM],
) -> DmTensor<D, Chip, Cluster, Slice, Element2>
pub fn parallel_copy_cluster_slice<'l, const CLUSTER_DIM: usize, AxisToSlice: M, AxisSlicedElement: M, Element2: M, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M>( &mut self, tensor: DmTensorView<'l, D, Chip, Cluster, Slice, Element>, slice_indices: &[usize; CLUSTER_DIM], ) -> DmTensor<D, Chip, Cluster, Slice, Element2>
Perform asymmetric cluster slice operation using ParallelCopy (stos command). This operation allows different clusters to select different slice positions.
Arguments
tensor- Input tensor with cluster dimensionslice_indices- Array of slice indices, one per cluster
Example
For Cluster=2 with slice_indices=[1,0]:
- Cluster 0 selects slice position 1
- Cluster 1 selects slice position 0
Restrictions
The AxisToSlice should be the outermost axis in Element.
Sourcepub fn parallel_copy_chip_slice<'l, const CHIP_DIM: usize, AxisToSlice: M, AxisSlicedElement: M, Element2: M, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M>(
&mut self,
tensor: DmTensorView<'l, D, Chip, Cluster, Slice, Element>,
slice_indices: &[usize; CHIP_DIM],
) -> DmTensor<D, Chip, Cluster, Slice, Element2>
pub fn parallel_copy_chip_slice<'l, const CHIP_DIM: usize, AxisToSlice: M, AxisSlicedElement: M, Element2: M, D: Scalar, Chip: M, Cluster: M, Slice: M, Element: M>( &mut self, tensor: DmTensorView<'l, D, Chip, Cluster, Slice, Element>, slice_indices: &[usize; CHIP_DIM], ) -> DmTensor<D, Chip, Cluster, Slice, Element2>
Perform asymmetric chip slice operation using ParallelCopy (stos command). This operation allows different chips to select different slice positions.
Arguments
tensor- Input tensor with chip dimensionslice_indices- Array of slice indices, one per chip
Example
For Chip=4 with slice_indices=[3,0,1,2]:
- Chip 0 selects slice position 3
- Chip 1 selects slice position 0
- Chip 2 selects slice position 1
- Chip 3 selects slice position 2