pub struct VeTensorData<S: Stage, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M, StashD: VeScalar, Stash: TensorState<StashD>, const VE_ORDER: VeOrder, FS: VeTensorContext = Standalone, const W: PacketMode = { Way8 }> { /* private fields */ }Expand description
Common tensor data for VE pipeline stages, without context reference. This expects sharing implementation between VectorTensor and VectorTensorPair groups.
The S type parameter represents the current pipeline stage.
The FS type parameter represents the filter state.
The StashD type parameter represents the scalar type of the stash tensor.
The Stash type parameter represents the stash type (for compile-time type checking).
The W type parameter represents the packet mode (Way8 or Way4).
Implementations
Sourceimpl<S: Stage, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M, StashD: VeScalar, Stash: TensorState<StashD>, FS: VeTensorContext, const W: PacketMode, const VE_ORDER: VeOrder> VeTensorData<S, D, Chip, Cluster, Slice, Time, Packet, StashD, Stash, VE_ORDER, FS, W>
impl<S: Stage, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M, StashD: VeScalar, Stash: TensorState<StashD>, FS: VeTensorContext, const W: PacketMode, const VE_ORDER: VeOrder> VeTensorData<S, D, Chip, Cluster, Slice, Time, Packet, StashD, Stash, VE_ORDER, FS, W>
Sourcepub fn ve_state_mut(&mut self) -> &mut VeState<StashD, Stash>
pub fn ve_state_mut(&mut self) -> &mut VeState<StashD, Stash>
Returns a mutable reference to the VE state.
Sourcepub fn inner(
&self,
) -> &Tensor<D, Pair<Chip, Pair<Cluster, Pair<Slice, Pair<Time, Packet>>>>>
pub fn inner( &self, ) -> &Tensor<D, Pair<Chip, Pair<Cluster, Pair<Slice, Pair<Time, Packet>>>>>
Returns a reference to the inner tensor.
Sourceimpl<S: Stashable, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M, const W: PacketMode, const VE_ORDER: VeOrder> VeTensorData<S, D, Chip, Cluster, Slice, Time, Packet, D, NoTensor, VE_ORDER, Standalone, W>
impl<S: Stashable, D: VeScalar, Chip: M, Cluster: M, Slice: M, Time: M, Packet: M, const W: PacketMode, const VE_ORDER: VeOrder> VeTensorData<S, D, Chip, Cluster, Slice, Time, Packet, D, NoTensor, VE_ORDER, Standalone, W>
Sourcepub fn stash(
self,
) -> VeTensorData<S, D, Chip, Cluster, Slice, Time, Packet, D, HasTensor<D, Pair<Chip, Pair<Cluster, Pair<Slice, Pair<Time, Packet>>>>>, VE_ORDER, Standalone, W>
pub fn stash( self, ) -> VeTensorData<S, D, Chip, Cluster, Slice, Time, Packet, D, HasTensor<D, Pair<Chip, Pair<Cluster, Pair<Slice, Pair<Time, Packet>>>>>, VE_ORDER, Standalone, W>
Writes the current tensor data to the operand register. The data can later be read using VeRhs::Stash in binary operations. Returns a new VeTensorData with the stash’s mapping set to the current tensor’s mapping.