pub trait AtomExt {
// Required methods
fn size(&self) -> usize;
fn idents(&self) -> RVec<Ident>;
fn contains_ident(&self, ident: Ident) -> bool;
fn find_symbol_size(&self, ident: Ident) -> ROption<usize>;
}Expand description
Methods for Atom.
Required Methods
Sourcefn contains_ident(&self, ident: Ident) -> bool
fn contains_ident(&self, ident: Ident) -> bool
Returns true if this atom contains the given ident (recursively).
Sourcefn find_symbol_size(&self, ident: Ident) -> ROption<usize>
fn find_symbol_size(&self, ident: Ident) -> ROption<usize>
Returns the original declared size of the given ident’s Symbol.