pub trait VeScalar: Scalar {
const KIND: VeScalarKind;
}Expand description
Marker trait for scalar types supported by Vector Engine. Only i32 and f32 are supported.
This trait is sealed and cannot be implemented outside this module.
Required Associated Constants
Sourceconst KIND: VeScalarKind
const KIND: VeScalarKind
The kind of this scalar type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.